
//  ****************************************************************************************
//
//  Internationales Bakenprojekt
//
//  Leuchtfeuer auf Kurzwelle, IARU Baken
//
//  Über die Welt verteilt sind automatisch arbeitende Sender installiert, 
//  sogenannte Baken, die ihre Kennung in Morsezeichen senden. Kann ein 
//  Funkamateur ihre Signale empfangen und kennt er den Zeitplan und die
//  Standorte der Baken, kann er sich schnell einen Überblick über die 
//  aktuellen Funkbedingungen auf den Kurzwellenbändern des Amateurfunk 
//  verschaffen.
//  Eine Bake des Internationalen Bakenprojekt sendet auf einer Frequenz 
//  für zehn Sekunden, dann wechselt die Amateurfunk Bake in ein anderes 
//  Frequenzband. Auf die zuvor benutze Frequenz wechselt eine andere Bake.
//  Jeweils fünf Baken senden gleichzeitig in fünf unterschiedlichen 
//  Amateurfunk Frequenzbändern. Ein kompletter Durchlauf über alle 18 Baken 
//  dauert drei Minuten, dann beginnt der Zyklus von vorne.
//  Die Baken senden erst ihr Rufzeichen, und anschliessend einen 4 Sekunden 
//  Dauerton dessen Sendeleistung stufenweise von 100 W, 10 W, 1 W auf 0,1 W 
//  verringert wird. So kann ein Funkamateur einschätzen welche Frequenzbänder 
//  nutzbar sind, und welche Sendeleistung erforderlich ist um einen Erdteil 
//  zu erreichen.
//  In der Regel wird man sich eine Frequenz aussuchen, und einen kompletten 
//  Durchlauf von drei Minuten über alle 18 Baken abwarten welche Signale man 
//  hören kann.
//
//  Zitat von http://www.dl1dlf.de/internationales-bakenprojekt


//  International Beacons nach MFX DX BEACON MONITOR 2017
//  The International Beacon Network is a worldwide network of high-frequency
//  radio beacons on 14.100, 18.110, 21.150, 24.930, and 28.200 MHz.
//
//  Die Zeitbasis ist ein Softwaretimer im Raster von 3 Minuten.
//  Synchronisation der Zeitbasis mittels Taste
//
//  (c) Jan von Kölle 14.07.2017 V0.0
//
//  ****************************************************************************************

// Import Standard Library
#include <LiquidCrystal.h>                    // Software LCD library

// Import Fremd Library
#include <Time.h>                             // Software timer library

//  ****************************************************************************************

// LCD Anschluß
LiquidCrystal lcd(8, 9, 4, 5, 6, 7);          // lcd (rs, enable, d0, d1, d2, d3)

//  ****************************************************************************************

static const char * call[] = {
                    "4U1UN ",           //  1 nach MFX DX BEACON MONITOR 2017 (USA Osten)
                    "VE8AT ",           //  2 nach MFX DX BEACON MONITOR 2017 (Canada)
                    "W6WX  ",           //  3 nach MFX DX BEACON MONITOR 2017 (USA Westen)
                    "KH6RS ",           //  4 nach MFX DX BEACON MONITOR 2017
                    "ZL6B  ",           //  5 nach MFX DX BEACON MONITOR 2017
                    "VK6RBP",           //  6 nach MFX DX BEACON MONITOR 2017
                    "JA2IGY",           //  7 nach MFX DX BEACON MONITOR 2017
                    "RR9O  ",           //  8 nach MFX DX BEACON MONITOR 2017 (Russia)
                    "VR2B  ",           //  9 nach MFX DX BEACON MONITOR 2017
                    "4S7B  ",           // 10 nach MFX DX BEACON MONITOR 2017
                    "ZS6DN ",           // 11 nach MFX DX BEACON MONITOR 2017
                    "5Z4B  ",           // 12 nach MFX DX BEACON MONITOR 2017
                    "4X6TU ",           // 13 nach MFX DX BEACON MONITOR 2017
                    "OH2B  ",           // 14 nach MFX DX BEACON MONITOR 2017
                    "CS3B  ",           // 15 nach MFX DX BEACON MONITOR 2017
                    "LU4AA ",           // 16 nach MFX DX BEACON MONITOR 2017
                    "OA4B  ",           // 17 nach MFX DX BEACON MONITOR 2017
                    "YV5B  "            // 18 nach MFX DX BEACON MONITOR 2017
                  };
                  
static const char * country[] = {
                    "New York    ",     //  1 nach MFX DX BEACON MONITOR 2017 (USA Osten)
                    "Nunavut     ",     //  2 nach MFX DX BEACON MONITOR 2017 (Canada)
                    "California  ",     //  3 nach MFX DX BEACON MONITOR 2017 (USA Westen)
                    "Hawaii      ",     //  4 nach MFX DX BEACON MONITOR 2017
                    "New Zealand ",     //  5 nach MFX DX BEACON MONITOR 2017
                    "Australia   ",     //  6 nach MFX DX BEACON MONITOR 2017
                    "Japan       ",     //  7 nach MFX DX BEACON MONITOR 2017
                    "Siberia     ",     //  8 nach MFX DX BEACON MONITOR 2017 (Russia)
                    "Hong Kong   ",     //  9 nach MFX DX BEACON MONITOR 2017
                    "Sri Lanka   ",     // 10 nach MFX DX BEACON MONITOR 2017
                    "SouthAfrica ",     // 11 nach MFX DX BEACON MONITOR 2017
                    "Kenya       ",     // 12 nach MFX DX BEACON MONITOR 2017
                    "Israel      ",     // 13 nach MFX DX BEACON MONITOR 2017
                    "Finland     ",     // 14 nach MFX DX BEACON MONITOR 2017
                    "Madeira     ",     // 15 nach MFX DX BEACON MONITOR 2017
                    "Argentina   ",     // 16 nach MFX DX BEACON MONITOR 2017
                    "Peru        ",     // 17 nach MFX DX BEACON MONITOR 2017
                    "Venezuela   "      // 18 nach MFX DX BEACON MONITOR 2017
                  };

// The beacons transmit on 5 frequencies
static const char * band[] = {
                  "14.100MHz",
                  "18.110MHz",
                  "21.150MHz",
                  "24.930MHz",
                  "28.200MHz"
                };

//  ****************************************************************************************

// Variablen Steuerung Ausgabe Beacon
int  cntNeuCall = 0;                          // The counter new of 18 beacons
int  cntAltCall = 1;                          // The counter old of 18 beacons
int  cntNeuBand = 0;                          // The counter new of 5 bands
int  cntAltBand = 1;                          // The counter old of 5 bands
int  cntTimeCall = 0;                         // The counter timer of Call

int  cntAltTime, cntNeuTime;                  // The counter of beacontimer

// Minute und Sekunde, Altwert und Neuwert
int istMinute  = 0;                           // Neuwert Minute
int altMinute  = 1;                           // Altwert Minute
int istSekunde = 0;                           // Neuwert Sekunde
int altSekunde = 1;                           // Altwert Sekunde

// Variablen Tastenabfrage
int TasteAnalogIn;
int TasteNummerAlt, TasteNummerNeu;

//  ****************************************************************************************

void setup() 
  {
    lcd.begin(16, 2);                         // LCD initialisieren

    lcd.setCursor(0, 0);                      // 1. Position in 1. Zeile
    lcd.print("Internationales ");
    lcd.setCursor(0, 1);                      // 1. Position in 2. Zeile
    lcd.print("Bakenprojekt SFB");

    delay(1000);

    // setTime(SollStunde, SollMinute, SollSekunde, SollTag, SollMonat, SollJahr);
    setTime(0, 0, 0, 20, 07, 2017);           // Uhr initialisieren
  }

//  ****************************************************************************************

void loop()
  {
    ZeitLesen();                              // Softwaretimer Minute und Sekunde lesen
    Taste();                                  // Tastenabfrage

    ZeitAusgabe();                            // Zeitanzeige aktualisieren
    BeaconAktiv();                            // aktive Beacon ermitteln
    BandWechsel();                            // Frequenz aktualisieren
    BeaconWechsel();                          // Beacon Call und Ort aktualisieren

    Aktualisierung();                         // Dynamische Werte aktualisien
  }

//  ****************************************************************************************



